@@ -21,6 +21,7 @@ package configs
 import (
 	"fmt"
 	"math"
+	"reflect"
 	"regexp"
 	"strings"
 	"time"
@@ -146,59 +147,59 @@ func checkLimitResource(cur QueueConfig, users map[string]map[string]*resources.
 		curQueuePath = queuePath + DOT + cur.Name
 	}
 
-	// Carry forward (populate) the parent limit settings to the next level if limits are not configured for the current queue
-	if len(cur.Limits) == 0 {
-		if _, ok := users[queuePath]; ok {
-			users[curQueuePath] = users[queuePath]
+	users[curQueuePath] = make(map[string]*resources.Resource)
+	groups[curQueuePath] = make(map[string]*resources.Resource)
+
+	// Carry forward (populate) the parent limit settings to the next level
+	for u, v := range users[queuePath] {
+		users[curQueuePath][u] = v.Clone()
+	}
+	for g, v := range groups[queuePath] {
+		groups[curQueuePath][g] = v.Clone()
+	}
+
+	// compare user & group limit setting between the current queue and parent queue
+	for _, limit := range cur.Limits {
+		limitMaxResources, err := resources.NewResourceFromConf(limit.MaxResources)
+		if err != nil {
+			return err
 		}
-		if _, ok := groups[queuePath]; ok {
-			groups[curQueuePath] = groups[queuePath]
+
+		for _, user := range limit.Users {
+			// Is user limit setting exists?
+			if userMaxResource, ok := users[queuePath][user]; ok {
+				if !userMaxResource.FitInMaxUndef(limitMaxResources) {
+					return fmt.Errorf("user %s max resource %s of queue %s is greater than immediate or ancestor parent maximum resource %s", user, limitMaxResources.String(), cur.Name, userMaxResource.String())
+				}
+				users[curQueuePath][user] = resources.ComponentWiseMinPermissive(limitMaxResources, userMaxResource)
+			} else if wildcardMaxResource, ok := users[queuePath][common.Wildcard]; user != common.Wildcard && ok {
+				if !wildcardMaxResource.FitInMaxUndef(limitMaxResources) {
+					return fmt.Errorf("user %s max resource %s of queue %s is greater than wildcard maximum resource %s of immediate or ancestor parent queue", user, limitMaxResources.String(), cur.Name, wildcardMaxResource.String())
+				}
+				users[curQueuePath][user] = limitMaxResources
+			} else {
+				users[curQueuePath][user] = limitMaxResources
+			}
 		}
-	} else {
-		// compare user & group limit setting between the current queue and parent queue
-		for _, limit := range cur.Limits {
-			limitMaxResources, err := resources.NewResourceFromConf(limit.MaxResources)
-			if err != nil {
-				return err
-			}
-			for _, user := range limit.Users {
-				// Is user limit setting exists?
-				if userMaxResource, ok := users[queuePath][user]; ok {
-					if !userMaxResource.FitInMaxUndef(limitMaxResources) {
-						return fmt.Errorf("user %s max resource %s of queue %s is greater than immediate or ancestor parent maximum resource %s", user, limitMaxResources.String(), cur.Name, userMaxResource.String())
-					}
-					// Override with min resource
-					if _, ok := users[curQueuePath]; !ok {
-						users[curQueuePath] = make(map[string]*resources.Resource)
-					}
-					users[curQueuePath][user] = resources.ComponentWiseMinPermissive(limitMaxResources, userMaxResource)
-				} else {
-					if _, ok := users[curQueuePath]; !ok {
-						users[curQueuePath] = make(map[string]*resources.Resource)
-					}
-					users[curQueuePath][user] = limitMaxResources
+		for _, group := range limit.Groups {
+			// Is group limit setting exists?
+			if groupMaxResource, ok := groups[queuePath][group]; ok {
+				if !groupMaxResource.FitInMaxUndef(limitMaxResources) {
+					return fmt.Errorf("group %s max resource %s of queue %s is greater than immediate or ancestor parent maximum resource %s", group, limitMaxResources.String(), cur.Name, groupMaxResource.String())
 				}
-			}
-			for _, group := range limit.Groups {
-				// Is group limit setting exists?
-				if groupMaxResource, ok := groups[queuePath][group]; ok {
-					if !groupMaxResource.FitInMaxUndef(limitMaxResources) {
-						return fmt.Errorf("group %s max resource %s of queue %s is greater than immediate or ancestor parent maximum resource %s", group, limitMaxResources.String(), cur.Name, groupMaxResource.String())
-					}
-					// Override with min resource
-					if _, ok := groups[curQueuePath]; !ok {
-						groups[curQueuePath] = make(map[string]*resources.Resource)
-					}
-					groups[curQueuePath][group] = resources.ComponentWiseMinPermissive(limitMaxResources, groupMaxResource)
-				} else {
-					if _, ok := groups[curQueuePath]; !ok {
-						groups[curQueuePath] = make(map[string]*resources.Resource)
-					}
-					groups[curQueuePath][group] = limitMaxResources
+				// Override with min resource
+				groups[curQueuePath][group] = resources.ComponentWiseMinPermissive(limitMaxResources, groupMaxResource)
+			} else if wildcardMaxResource, ok := groups[queuePath][common.Wildcard]; group != common.Wildcard && ok {
+				if !wildcardMaxResource.FitInMaxUndef(limitMaxResources) {
+					return fmt.Errorf("group %s max resource %s of queue %s is greater than wildcard maximum resource %s of immediate or ancestor parent queue", group, limitMaxResources.String(), cur.Name, wildcardMaxResource.String())
 				}
+				groups[curQueuePath][group] = limitMaxResources
+			} else {
+				groups[curQueuePath][group] = limitMaxResources
 			}
 		}
 	}
+
 	// traverse child queues
 	for _, child := range cur.Queues {
 		err := checkLimitResource(child, users, groups, curQueuePath)
@@ -212,9 +213,12 @@ func checkLimitResource(cur QueueConfig, users map[string]map[string]*resources.
 func checkQueueMaxApplications(cur QueueConfig) error {
 	var err error
 	for _, child := range cur.Queues {
-		if cur.MaxApplications != 0 && (cur.MaxApplications < child.MaxApplications || child.MaxApplications == 0) {
+		if cur.MaxApplications != 0 && cur.MaxApplications < child.MaxApplications {
 			return fmt.Errorf("parent maxApplications must be larger than child maxApplications")
 		}
+		if cur.MaxApplications != 0 && child.MaxApplications == 0 {
+			return fmt.Errorf("maxApplications is either undefined or zero, which is not allowed when parent queue's maxApplications is defined")
+		}
 		err = checkQueueMaxApplications(child)
 		if err != nil {
 			return err
@@ -231,54 +235,53 @@ func checkLimitMaxApplications(cur QueueConfig, users map[string]map[string]uint
 		curQueuePath = queuePath + DOT + cur.Name
 	}
 
-	// Carry forward (populate) the parent limit settings to the next level if limits are not configured for the current queue
-	if len(cur.Limits) == 0 {
-		if _, ok := users[queuePath]; ok {
-			users[curQueuePath] = users[queuePath]
-		}
-		if _, ok := groups[queuePath]; ok {
-			groups[curQueuePath] = groups[queuePath]
-		}
-	} else {
-		// compare user & group limit setting between the current queue and parent queue
-		for _, limit := range cur.Limits {
-			limitMaxApplications := limit.MaxApplications
-			for _, user := range limit.Users {
-				// Is user limit setting exists?
-				if userMaxApplications, ok := users[queuePath][user]; ok {
-					if userMaxApplications != 0 && (userMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
-						return fmt.Errorf("user %s max applications %d of queue %s is greater than immediate or ancestor parent max applications %d", user, limitMaxApplications, cur.Name, userMaxApplications)
-					}
-					// Override with min resource
-					if _, ok := users[curQueuePath]; !ok {
-						users[curQueuePath] = make(map[string]uint64)
-					}
-					users[curQueuePath][user] = common.Min(limitMaxApplications, userMaxApplications)
-				} else {
-					if _, ok := users[curQueuePath]; !ok {
-						users[curQueuePath] = make(map[string]uint64)
-					}
-					users[curQueuePath][user] = limitMaxApplications
-				}
-			}
+	users[curQueuePath] = make(map[string]uint64)
+	groups[curQueuePath] = make(map[string]uint64)
 
-			for _, group := range limit.Groups {
-				// Is user limit setting exists?
-				if groupMaxApplications, ok := groups[queuePath][group]; ok {
-					if groupMaxApplications != 0 && (groupMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
-						return fmt.Errorf("group %s max applications %d of queue %s is greater than immediate or ancestor parent max applications %d", group, limitMaxApplications, cur.Name, groupMaxApplications)
-					}
-					// Override with min resource
-					if _, ok := groups[curQueuePath]; !ok {
-						groups[curQueuePath] = make(map[string]uint64)
-					}
-					groups[curQueuePath][group] = common.Min(limitMaxApplications, groupMaxApplications)
-				} else {
-					if _, ok := groups[curQueuePath]; !ok {
-						groups[curQueuePath] = make(map[string]uint64)
-					}
-					groups[curQueuePath][group] = limitMaxApplications
+	// Carry forward (populate) the parent limit settings to the next level
+	// queuePath is the parent queue path and curQueuePath is the current queue path.
+	// For example, queuePath is root and curQueuePath is root.current.
+	for u, maxapplications := range users[queuePath] {
+		users[curQueuePath][u] = maxapplications
+	}
+	for g, maxapplications := range groups[queuePath] {
+		groups[curQueuePath][g] = maxapplications
+	}
+
+	// compare user & group limit setting between the current queue and parent queue
+	for _, limit := range cur.Limits {
+		limitMaxApplications := limit.MaxApplications
+		for _, user := range limit.Users {
+			// Is user limit setting exists?
+			if userMaxApplications, ok := users[queuePath][user]; ok {
+				if userMaxApplications != 0 && (userMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
+					return fmt.Errorf("user %s max applications %d of queue %s is greater than immediate or ancestor parent max applications %d", user, limitMaxApplications, cur.Name, userMaxApplications)
 				}
+				users[curQueuePath][user] = limitMaxApplications
+			} else if wildcardMaxApplications, ok := users[queuePath][common.Wildcard]; user != common.Wildcard && ok {
+				if wildcardMaxApplications != 0 && (wildcardMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
+					return fmt.Errorf("user %s max applications %d of queue %s is greater than wildcard max applications %d of immediate or ancestor parent queue", user, limitMaxApplications, cur.Name, wildcardMaxApplications)
+				}
+				users[curQueuePath][user] = limitMaxApplications
+			} else {
+				users[curQueuePath][user] = limitMaxApplications
+			}
+		}
+
+		for _, group := range limit.Groups {
+			// Is user limit setting exists?
+			if groupMaxApplications, ok := groups[queuePath][group]; ok {
+				if groupMaxApplications != 0 && (groupMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
+					return fmt.Errorf("group %s max applications %d of queue %s is greater than immediate or ancestor parent max applications %d", group, limitMaxApplications, cur.Name, groupMaxApplications)
+				}
+				groups[curQueuePath][group] = limitMaxApplications
+			} else if wildcardMaxApplications, ok := groups[queuePath][common.Wildcard]; group != common.Wildcard && ok {
+				if wildcardMaxApplications != 0 && (wildcardMaxApplications < limitMaxApplications || limitMaxApplications == 0) {
+					return fmt.Errorf("group %s max applications %d of queue %s is greater than wildcard max applications %d of immediate or ancestor parent queue", group, limitMaxApplications, cur.Name, wildcardMaxApplications)
+				}
+				groups[curQueuePath][group] = limitMaxApplications
+			} else {
+				groups[curQueuePath][group] = limitMaxApplications
 			}
 		}
 	}
@@ -539,8 +542,8 @@ func checkLimit(limit Limit, existedUserName map[string]bool, existedGroupName m
 				zap.Error(err))
 			return err
 		}
-		if resources.IsZero(limitResource) {
-			return fmt.Errorf("MaxResources is zero in '%s' limit, all resource types are zero", limit.Limit)
+		if !resources.StrictlyGreaterThanZero(limitResource) {
+			return fmt.Errorf("MaxResources should be greater than zero in '%s' limit", limit.Limit)
 		}
 	}
 	// at least some resource should be not null
@@ -591,6 +594,26 @@ func checkLimits(limits []Limit, obj string, queue *QueueConfig) error {
 	return nil
 }
 
+func checkLimitsStructure(partitionConfig *PartitionConfig) error {
+	partitionLimits := partitionConfig.Limits
+	rootQueue := &partitionConfig.Queues[0]
+
+	if len(partitionConfig.Queues) < 1 || strings.ToLower(rootQueue.Name) != RootQueue {
+		return fmt.Errorf("top queue name is %s not root", rootQueue.Name)
+	}
+
+	if len(partitionLimits) > 0 && len(rootQueue.Limits) > 0 && !reflect.DeepEqual(partitionLimits, rootQueue.Limits) {
+		return fmt.Errorf("partition limits and root queue limits are not equivalent")
+	}
+
+	// if root queue limits not defined, apply partition limits
+	if len(partitionLimits) > 0 && len(rootQueue.Limits) == 0 {
+		rootQueue.Limits = partitionLimits
+	}
+
+	return nil
+}
+
 // Check for global policy
 func checkNodeSortingPolicy(partition *PartitionConfig) error {
 	// get the policy
@@ -702,14 +725,6 @@ func checkQueuesStructure(partition *PartitionConfig) error {
 	if rootQueue.Resources.Guaranteed != nil || rootQueue.Resources.Max != nil {
 		return fmt.Errorf("root queue must not have resource limits set")
 	}
-	return checkQueues(&rootQueue, 1)
-}
-
-// Check the state dump file path, if configured, is a valid path that can be written to.
-func checkDeprecatedStateDumpFilePath(partition *PartitionConfig) error {
-	if partition.StateDumpFilePath != "" {
-		log.Log(log.Deprecation).Warn("Ignoring deprecated partition setting 'statedumpfilepath'. This parameter will be removed in a future release.")
-	}
 	return nil
 }
 
@@ -730,7 +745,8 @@ func Validate(newConfig *SchedulerConfig) error {
 
 	// check uniqueness
 	partitionMap := make(map[string]bool)
-	for i, partition := range newConfig.Partitions {
+	for i := range newConfig.Partitions {
+		partition := newConfig.Partitions[i]
 		if partition.Name == "" || strings.ToLower(partition.Name) == DefaultPartition {
 			partition.Name = DefaultPartition
 		}
@@ -743,6 +759,14 @@ func Validate(newConfig *SchedulerConfig) error {
 		if err != nil {
 			return err
 		}
+		err = checkLimitsStructure(&partition)
+		if err != nil {
+			return err
+		}
+		err = checkQueues(&partition.Queues[0], 1)
+		if err != nil {
+			return err
+		}
 		_, err = checkQueueResource(partition.Queues[0], nil)
 		if err != nil {
 			return err
@@ -751,18 +775,11 @@ func Validate(newConfig *SchedulerConfig) error {
 		if err != nil {
 			return err
 		}
-		err = checkLimits(partition.Limits, partition.Name, &partition.Queues[0])
-		if err != nil {
-			return err
-		}
 		err = checkNodeSortingPolicy(&partition)
 		if err != nil {
 			return err
 		}
-		err = checkDeprecatedStateDumpFilePath(&newConfig.Partitions[i])
-		if err != nil {
-			return err
-		}
+
 		err = checkQueueMaxApplications(partition.Queues[0])
 		if err != nil {
 			return err
