@@ -2232,6 +2232,94 @@ func TestAssumePod_PodNotFound(t *testing.T) {
 	assert.Equal(t, podInCache.Spec.NodeName, "", "NodeName in pod spec was set unexpectedly")
 }
 
+// TestOriginatorPodAfterRestart Test to ensure originator pod remains same even after restart. After restart, ordering of pods may change which can lead to
+// incorrect originator pod selection. Instead of doing actual restart, create a situation where in pods are being processed in any random order.
+// For example, placeholders are processed first and then real driver pod.
+// Ensure ordering of pods doesn't have any impact on the originator.
+func TestOriginatorPodAfterRestart(t *testing.T) {
+	context := initContextForTest()
+	controller := false
+	blockOwnerDeletion := true
+	ref := apis.OwnerReference{
+		APIVersion:         "v1",
+		Kind:               "Pod",
+		Name:               "originator-01",
+		UID:                "UID-00001",
+		Controller:         &controller,
+		BlockOwnerDeletion: &blockOwnerDeletion,
+	}
+	ownerRefs := []apis.OwnerReference{ref}
+
+	// Real driver pod
+	pod1 := &v1.Pod{
+		TypeMeta: apis.TypeMeta{
+			Kind:       "Pod",
+			APIVersion: "v1",
+		},
+		ObjectMeta: apis.ObjectMeta{
+			Name: "originator-01",
+			UID:  "UID-00001",
+			Labels: map[string]string{
+				"applicationId": "spark-app-01",
+				"queue":         "root.a",
+			},
+		},
+		Spec: v1.PodSpec{SchedulerName: "yunikorn"},
+	}
+
+	// Placeholder pod 1
+	pod2 := &v1.Pod{
+		TypeMeta: apis.TypeMeta{
+			Kind:       "Pod",
+			APIVersion: "v1",
+		},
+		ObjectMeta: apis.ObjectMeta{
+			Name: "placeholder-01",
+			UID:  "placeholder-01",
+			Labels: map[string]string{
+				"applicationId": "spark-app-01",
+				"queue":         "root.a",
+			},
+			Annotations: map[string]string{
+				constants.AnnotationPlaceholderFlag: "true",
+			},
+			OwnerReferences: ownerRefs, // Add owner references because every ph reuse the app placeholder owner references.
+		},
+		Spec: v1.PodSpec{SchedulerName: "yunikorn"},
+	}
+
+	// Placeholder pod 1
+	pod3 := &v1.Pod{
+		TypeMeta: apis.TypeMeta{
+			Kind:       "Pod",
+			APIVersion: "v1",
+		},
+		ObjectMeta: apis.ObjectMeta{
+			Name: "placeholder-02",
+			UID:  "placeholder-02",
+			Labels: map[string]string{
+				"applicationId": "spark-app-01",
+				"queue":         "root.a",
+			},
+			Annotations: map[string]string{
+				constants.AnnotationPlaceholderFlag: "true",
+			},
+			OwnerReferences: ownerRefs, // Add owner references because every ph reuse the app placeholder owner references.
+		},
+		Spec: v1.PodSpec{SchedulerName: "yunikorn"},
+	}
+
+	// Add the ph pods first and then real driver pod at the last
+	context.AddPod(pod3)
+	context.AddPod(pod2)
+	context.AddPod(pod1)
+
+	app := context.getApplication("spark-app-01")
+	assert.Equal(t, app.originatingTask.taskID, "UID-00001")
+	assert.Equal(t, len(app.GetPlaceHolderTasks()), 2)
+	assert.Equal(t, len(app.GetAllocatedTasks()), 0)
+}
+
 func initAssumePodTest(binder *test.VolumeBinderMock) *Context {
 	context, apiProvider := initContextAndAPIProviderForTest()
 	if binder != nil {
@@ -2336,3 +2424,76 @@ func foreignPod(podName, memory, cpu string) *v1.Pod {
 		},
 	}
 }
+
+func TestRegisterPods(t *testing.T) {
+	context := initContextForTest()
+
+	pods, err := context.registerPods()
+	assert.NilError(t, err, "register pods with empty setup should not fail")
+	assert.Equal(t, len(pods), 0, "should have returned an empty pod list")
+
+	var api *client.MockedAPIProvider
+	switch v := context.apiProvider.(type) {
+	case *client.MockedAPIProvider:
+		api = v
+	default:
+		t.Fatalf("api type not recognized")
+	}
+	pod1 := newPodHelper("yunikorn-test-00001", namespace, "UID-00001", "node-1", "yunikorn-test-00001", v1.PodRunning)
+	pod2 := newPodHelper("yunikorn-test-00002", namespace, "UID-00002", "node-1", "yunikorn-test-00002", v1.PodRunning)
+	pod3 := newPodHelper("yunikorn-test-00003", namespace, "UID-00003", "node-1", "yunikorn-test-00003", v1.PodSucceeded)
+	pod4 := newPodHelper("yunikorn-test-00004", namespace, "UID-00004", "node-1", "yunikorn-test-00004", v1.PodRunning)
+
+	api.GetPodListerMock().AddPod(pod1)
+	api.GetPodListerMock().AddPod(pod2)
+	api.GetPodListerMock().AddPod(pod3)
+	api.GetPodListerMock().AddPod(pod4)
+
+	pods, err = context.registerPods()
+	assert.NilError(t, err, "register pods should not have failed")
+	assert.Assert(t, assertListerPods(pods, 3), "should have returned 3 running pods in the list")
+
+	pod1Cache, _ := context.schedulerCache.GetPod(string(pod1.UID))
+	assert.Assert(t, pod1Cache != nil, "expected to find pod 1 in cache")
+	pod2Cache, _ := context.schedulerCache.GetPod(string(pod2.UID))
+	assert.Assert(t, pod2Cache != nil, "expected to find pod 2 in cache")
+	pod3Cache, _ := context.schedulerCache.GetPod(string(pod3.UID))
+	assert.Assert(t, pod3Cache == nil, "not expected to find pod 3 in cache")
+	pod4Cache, _ := context.schedulerCache.GetPod(string(pod4.UID))
+	assert.Assert(t, pod4Cache != nil, "expected to find pod 4 in cache")
+
+	// prep for finalising the pods
+	// new pod added (should be ignored)
+	pod5 := newPodHelper("yunikorn-test-00005", namespace, "UID-00005", "node-1", "yunikorn-test-00005", v1.PodRunning)
+	api.GetPodListerMock().AddPod(pod5)
+	// update pod 1 is now marked as terminated (will be removed)
+	pod1.Status = v1.PodStatus{
+		Phase: v1.PodSucceeded,
+	}
+	api.GetPodListerMock().AddPod(pod1)
+	// remove pod 4 as if it was removed from K8s (will be removed)
+	api.GetPodListerMock().DeletePod(pod4)
+
+	err = context.finalizePods(pods)
+	assert.NilError(t, err, "finalize pods should not have failed")
+	pod1Cache, _ = context.schedulerCache.GetPod(string(pod1.UID))
+	assert.Assert(t, pod1Cache == nil, "not expected to find pod 1 in cache")
+	pod2Cache, _ = context.schedulerCache.GetPod(string(pod2.UID))
+	assert.Assert(t, pod2Cache != nil, "expected to find pod 2 in cache")
+	pod3Cache, _ = context.schedulerCache.GetPod(string(pod3.UID))
+	assert.Assert(t, pod3Cache == nil, "not expected to find pod 3 in cache")
+	pod4Cache, _ = context.schedulerCache.GetPod(string(pod4.UID))
+	assert.Assert(t, pod4Cache == nil, "not expected to find pod 4 in cache")
+	pod5Cache, _ := context.schedulerCache.GetPod(string(pod5.UID))
+	assert.Assert(t, pod5Cache == nil, "not expected to find pod 5 in cache")
+}
+
+func assertListerPods(pods []*v1.Pod, count int) bool {
+	counted := 0
+	for _, pod := range pods {
+		if pod != nil {
+			counted++
+		}
+	}
+	return count == counted
+}
