@@ -30,34 +30,55 @@ export class CommonUtil {
     return uniqid;
   }
 
-  static formatBytes(value: number | string): string {
-    const units: readonly string[] = ['kB', 'MB', 'GB', 'TB', 'PB'];
-    let unit: string = 'bytes';
-    let toValue = +value
+  static formatMemoryBytes(value: number | string): string {
+    const units: readonly string[] = ['KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB'];
+    let unit: string = 'B';
+    let toValue = +value;
+    for (let i = 0, unitslen = units.length; toValue / 1024 >= 1 && i < unitslen;i = i + 1) {
+      toValue = toValue / 1024;
+      unit = units[i];
+    }
+    return `${toValue.toLocaleString(undefined, { maximumFractionDigits: 2 })} ${unit}`;
+  }
+
+  static formatEphemeralStorageBytes(value: number | string): string {
+    const units: readonly string[] = ['kB', 'MB', 'GB', 'TB', 'PB', 'EB'];
+    let unit: string = 'B';
+    let toValue = +value;
     for (let i = 0, unitslen = units.length; toValue / 1000 >= 1 && i < unitslen;i = i + 1) {
       toValue = toValue / 1000;
       unit = units[i];
     }
-    return `${toValue.toFixed(1)} ${unit}`;
+    return `${toValue.toLocaleString(undefined, { maximumFractionDigits: 2 })} ${unit}`;
   }
 
   static isEmpty(arg: object | any[]): boolean {
     return Object.keys(arg).length === 0;
   }
 
-  static formatCount(value: number | string): string {
-    const unit = 'K';
-    const toValue = +value;
-    if (toValue >= 10000) {
-      return `${(toValue / 1000).toLocaleString(undefined, { maximumFractionDigits: 1 })} ${unit}`;
+  static formatCpuCore(value: number | string): string {
+    const units: readonly string[] = ['m', '', 'k', 'M', 'G', 'T', 'P', 'E'];
+    let unit: string = '';
+    let toValue = +value;
+    if (toValue > 0) {
+      unit = units[0];
     }
-
-    return toValue.toLocaleString();
+    for (let i = 1, unitslen = units.length; toValue / 1000 >= 1 && i < unitslen;i = i + 1) {
+      toValue = toValue / 1000;
+      unit = units[i];
+    }
+    return `${toValue.toLocaleString(undefined, { maximumFractionDigits: 2 })}${unit}`;
   }
 
   static formatOtherResource(value: number | string): string {
-    const toValue = +value;
-    return toValue.toLocaleString();
+    const units: readonly string[] = ['k', 'M', 'G', 'T', 'P', 'E'];
+    let unit: string = '';
+    let toValue = +value;
+    for (let i = 0, unitslen = units.length; toValue / 1000 >= 1 && i < unitslen;i = i + 1) {
+      toValue = toValue / 1000;
+      unit = units[i];
+    }
+    return `${toValue.toLocaleString(undefined, { maximumFractionDigits: 2 })}${unit}`;
   }
 
   static resourceColumnFormatter(value: string): string {
@@ -76,4 +97,22 @@ export class CommonUtil {
     }
     return NOT_AVAILABLE;
   }
+
+  static resourcesCompareFn(a: string, b: string): number {
+    // define the order of resources
+    const resourceOrder: { [key: string]: number } = {
+      "memory": 1,
+      "vcore": 2,
+      "pods": 3,
+      "ephemeral-storage": 4
+    };
+    const orderA = a in resourceOrder ? resourceOrder[a] : Number.MAX_SAFE_INTEGER;
+    const orderB = b in resourceOrder ? resourceOrder[b] : Number.MAX_SAFE_INTEGER;
+  
+    if (orderA !== orderB) {
+      return orderA - orderB;  // Resources in the order defined above
+    } else {
+      return a.localeCompare(b);  // Other resources will be in lexicographic order
+    }
+  }
 }
